==> tripleo-ui-1.0.5.3.ab54196.tar.gz: package/src/js/components/validations/ValidationStatusIcon.js <==
import React from 'react';
import { includes } from 'lodash';
import ClassNames from 'classnames';

export const ValidationStatusIcon = ({ status, triggerValidationAction }) => {
  const statusIconClass = ClassNames({
    'list-view-pf-icon-md':               true,
    'running fa fa-stop-circle':          status === 'running',
    'pficon pficon-error-circle-o front': status === 'failed',
    'pficon pficon-ok front':             status === 'success',
    'fa fa-play-circle':                  includes(['new', 'paused'], status),
    'pficon pficon-help':                 status === 'error'
  });

  const runValidationIconClass = 'list-view-pf-icon-md fa fa-play-circle back';

  switch (true) {
  case (includes(['new', 'running', 'paused'], status)):
    return (
      <a className="link"
         onClick={triggerValidationAction}>
        <span className={statusIconClass}/>
      </a>
    );
  case (includes(['success', 'failed'], status)):
    return (
      <a className="link flip-container"
         onClick={triggerValidationAction}>
        <div className="flipper">
          <span className={statusIconClass}/>
          <span className={runValidationIconClass}/>
        </div>
      </a>
    );
  default:
    return (
      <a className="link flip-container"
         onClick={triggerValidationAction}>
        <div className="flipper">
          <span className={statusIconClass}/>
          <span className={runValidationIconClass}/>
        </div>
      </a>
    );
  }
};
ValidationStatusIcon.propTypes = {
  status: React.PropTypes.string,
  triggerValidationAction: React.PropTypes.func.isRequired
};

==> tripleo-ui-7.0.0.42.3165323.tar.gz: package/src/js/components/validations/ValidationStatusIcon.js <==
import React, { PropTypes } from 'react';
import { includes } from 'lodash';
import ClassNames from 'classnames';

export const ValidationStatusIcon = ({ status, triggerValidationAction }) => {
  const statusIconClass = ClassNames({
    'list-view-pf-icon-md':               true,
    'running fa fa-stop-circle':          status === 'running',
    'pficon pficon-error-circle-o front': status === 'failed',
    'pficon pficon-ok front':             status === 'success',
    'fa fa-play-circle':                  includes(['new', 'paused'], status),
    'pficon pficon-help':                 status === 'error'
  });

  const runValidationIconClass = 'list-view-pf-icon-md fa fa-play-circle back';

  switch (true) {
  case (includes(['new', 'running', 'paused'], status)):
    return (
      <a className="link"
         onClick={triggerValidationAction}>
        <span className={statusIconClass}/>
      </a>
    );
  case (includes(['success', 'failed'], status)):
    return (
      <a className="link flip-container"
         onClick={triggerValidationAction}>
        <div className="flipper">
          <span className={statusIconClass}/>
          <span className={runValidationIconClass}/>
        </div>
      </a>
    );
  default:
    return (
      <a className="link flip-container"
         onClick={triggerValidationAction}>
        <div className="flipper">
          <span className={statusIconClass}/>
          <span className={runValidationIconClass}/>
        </div>
      </a>
    );
  }
};
ValidationStatusIcon.propTypes = {
  status: PropTypes.string,
  triggerValidationAction: PropTypes.func.isRequired
};
